#
# spec file for package orthanc-ohif
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2023-2024 Dr. Axel Braun <DocB@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           orthanc-ohif
Summary:        OHIF plugin for Orthanc
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
Version:        1.5
Release:        1.3
URL:            https://orthanc-server.com
Source0:        https://orthanc.uclouvain.be/downloads/sources/%{name}/OrthancOHIF-%{version}.tar.gz
Source1:        https://orthanc.uclouvain.be/downloads/linux-standard-base/orthanc-ohif/%{version}/dist.zip

BuildRequires:  cmake
BuildRequires:  e2fsprogs-devel
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  googletest-devel
BuildRequires:  jsoncpp-devel
BuildRequires:  libboost_date_time-devel >= 1.66
BuildRequires:  libboost_filesystem-devel >= 1.66
BuildRequires:  libboost_iostreams-devel >= 1.66
BuildRequires:  libboost_regex-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  openssl-devel
BuildRequires:  orthanc-devel
BuildRequires:  orthanc-source
BuildRequires:  pugixml-devel
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
BuildRequires:  uuid-devel
%if %{?suse_version} > 1550
BuildRequires:  python3-base >= 3.8
%define __mybuildpython %__python3
%else
BuildRequires:  %{python_module base >= 3.8}
%define __mybuildpython %{expand:%%__%pythons}
%endif

Requires:       orthanc

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
OHIF plugin for Orthanc
The homepage of OHIF can be found at:
https://ohif.org/

%prep
%autosetup -n OrthancOHIF-%{version}

#OrthanPlugins may ask for additional files to be loaded
#Putting them into this folder prevents download of sources from the web
#static assets of the OHIF viewer
mkdir OHIF
unzip %{S:1} -d OHIF

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
export CXX=g++-13
%endif
%cmake ../ \
       -DALLOW_DOWNLOADS=OFF \
       -DUSE_SYSTEM_GOOGLE_TEST=ON \
       -DUSE_SYSTEM_ORTHANC_SDK=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DBoost_NO_BOOST_CMAKE=ON \
       -DORTHANC_FRAMEWORK_ROOT=/usr/src/orthanc/OrthancFramework/Sources \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/ \
       -DPYTHON_EXECUTABLE=%{__mybuildpython}

%cmake_build %{?_smp_mflags}

%install

mkdir -p -m 755 %{buildroot}%{_docdir}/orthanc-ohif

%cmake_install

# architecture dependent files should not be in /usr/share...
# create a directory

mkdir -p -m 755 %{buildroot}%{_libdir}/share/orthanc/plugins

mv %{buildroot}%{_prefix}/share/orthanc/plugins/*.so* %{buildroot}%{_libdir}/share/orthanc/plugins/.

#orthanc expects the libs in the plugin-directory

ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancOHIF.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancOHIF.so

rm %{buildroot}%{_libdir}/share/orthanc/plugins/libOrthancOHIF.so

cp NEWS README %{buildroot}%{_docdir}/orthanc-ohif/.

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license LICENSES/*
%dir %{_docdir}/orthanc-ohif
%{_docdir}/orthanc-ohif/*
%dir %{_libdir}/share
%dir %{_libdir}/share/orthanc
%dir %{_libdir}/share/orthanc/plugins
%{_libdir}/share/orthanc/plugins/*.so*
%dir %{_prefix}/share/orthanc
%dir %{_prefix}/share/orthanc/plugins
%{_prefix}/share/orthanc/plugins/*.so*

%changelog
* Sun Jan 19 2025 Axel Braun <axel.braun@gmx.de>
- version 1.5
  * Updated OHIF to 3.9.2
  * In "dicom-web" data source, fixed the default "app-config.js"
    configuration to enable display of PDFs.
  * Updated cached "dicom-json" version to 2. This implies that, when using
    the "dicom-json" source, the cached metadata will have to be recomputed
    the first time you open a study.
* Sun Dec  8 2024 Axel Braun <axel.braun@gmx.de>
- license string corrected
* Sat Nov 30 2024 Axel Braun <axel.braun@gmx.de>
- version 1.4
  * Updated OHIF to 3.9.1
  * The default value for the "DataSource" configuration is now "dicom-web"
    instead of "dicom-json" since "dicom-web" is usually
    more optimized.
* Fri Jul 12 2024 Axel Braun <axel.braun@gmx.de>
- version 1.3
  * Updated OHIF to 3.8.3
  * Enabled support for segmentation and microscopy modes
    Note that the microscopy mode is not stable yet in OHIF!
  * Fixed wrong MIME type for app-config.js that prevents the OHIF
    viewer from loading with Orthanc 1.12.2
* Wed Mar 13 2024 Axel Braun <axel.braun@gmx.de>
- enable gcc13 for Leap 15
* Wed Jan  3 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use dist.zip related to version 1.1, not nightly build.
* Thu Dec  7 2023 Ben Greiner <code@bnavigator.de>
- Force Python > 3.8 for the build stage
* Tue Nov 28 2023 Axel Braun <axel.braun@gmx.de>
- version 1.1
  * Download moved to https://orthanc.uclouvain.be/downloads/sources/
  * Updated OHIF to 3.7.0
  * The default configuration has been adapted to avoid unneccesary
    transcoding on Orthanc side
  * Patch to make the build of static assets reproducible, following a
  suggestion by Bernhard M. Wiedemann (bwiedemann@suse.de)
* Mon Jun 19 2023 Axel Braun <axel.braun@gmx.de>
- version 1.0
  Initial OBS build
